@@ -22,11 +22,7 @@ import twitter4j.TwitterException;
 import twitter4j.TwitterFactory;
 import twitter4j.json.DataObjectFactory;
 
-import java.io.BufferedWriter;
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.OutputStreamWriter;
+import java.io.*;
 import java.util.List;
 
 /**
@@ -45,7 +41,7 @@ public final class SaveRawJSON {
         System.out.println("Saving public timeline.");
         try {
             new File("statuses").mkdir();
-            List<Status> statuses = twitter.getPublicTimeline();
+            List<Status> statuses = twitter.getHomeTimeline();
             for (Status status : statuses) {
                 String rawJSON = DataObjectFactory.getRawJSON(status);
                 String fileName = "statuses/" + status.getId() + ".json";
@@ -75,19 +71,19 @@ public final class SaveRawJSON {
             bw.write(rawJSON);
             bw.flush();
         } finally {
-            if (null != bw) {
+            if (bw != null) {
                 try {
                     bw.close();
                 } catch (IOException ignore) {
                 }
             }
-            if (null != osw) {
+            if (osw != null) {
                 try {
                     osw.close();
                 } catch (IOException ignore) {
                 }
             }
-            if (null != fos) {
+            if (fos != null) {
                 try {
                     fos.close();
                 } catch (IOException ignore) {
